@@ -7,37 +7,7 @@ from typing import Any, Dict, List, Optional
 
 from pydantic import AnyHttpUrl, BaseModel, Field, stricturl
 
-
-class MessageTypeEnum(str, Enum):
-    text = "text"
-    image = "image"
-    audio = "audio"
-    video = "video"
-    file = "file"
-    location = "location"
-    contact = "contact"
-    template = "template"
-    sticker = "sticker"
-
-
-class ActionToTypeEnum(str, Enum):
-    """ActionToTypeEnum
-
-    Actions types.
-    """
-
-    contact = "contact"
-    owner = "owner"
-    bot = "bot"
-    plugin = "plugin"
-    devops = "devops"
-    webhook = "webhook"
-    system = "system"
-
-
-# class DasFileUrl(AnyHttpUrl):
-#     allowed_schemes = ["https", "http"]
-#     tld_required = False
+from .types import MessageDispatchEnum, MessageTypeEnum
 
 
 class Config(BaseModel):
@@ -366,8 +336,14 @@ class MessageSchema(BaseModel):
     class Config:
         validate_assignment = True
 
+    dispatch: MessageDispatchEnum = Field(
+        MessageDispatchEnum.gateway,
+        title="Dispatch Module",
+        description="Dispatch message with this module",
+        example="gateway",
+    )
     message_type: MessageTypeEnum = Field(
-        MessageTypeEnum.text, title="Type", description="Message type.", example="text"
+        MessageTypeEnum.text, title="Type", description="Message type", example="text"
     )
     content: str = Field(
         ...,
@@ -377,6 +353,20 @@ class MessageSchema(BaseModel):
         example="This is a message content.",
     )
     metadata: Optional[MediaMetaData]
+    agent_id: str = Field(
+        None,
+        max_length=64,
+        title="Agent ID",
+        description="ID of the agent who wrote the message.",
+        example="BxdYnAjpu3PTciw6Z",
+    )
+    agent_name: str = Field(
+        "Bot",
+        max_length=64,
+        title="Agent Name",
+        description="Name of the agent.",
+        example="Ruth A.",
+    )
 
 
 class HandsoffInfoDataSchema(BaseModel):
@@ -427,3 +417,60 @@ class HandsoffInfoSchema(BaseModel):
     data: HandsoffInfoDataSchema = Field(
         ..., title="Data", description="Handsoff app data."
     )
+
+
+class ChannelConfig(BaseModel):
+    class Config:
+        validate_assignment = True
+
+    app: str = Field(
+        ...,
+        max_length=255,
+        title="Label",
+        description="App ID",
+        example="Channel App ID",
+    )
+    channel_type: str = Field(
+        ...,
+        max_length=25,
+        title="Channel Type",
+        description="Channel type",
+        example="whatsapp",
+    )
+    endpoint: AnyHttpUrl = Field(
+        ...,
+        title="Api Endpoint",
+        description="Channel API endpoint. Needs to be HTTPS",
+        example="https://api.gupshup.io",
+    )
+    user: str = Field(
+        None,
+        max_length=256,
+        title="User",
+        description="Channel user if needed",
+        example="email@domain.com",
+    )
+    password: str = Field(
+        None,
+        max_length=64,
+        title="Password",
+        description="Channel password if needed",
+        example="SomeGoodPassword",
+    )
+    api_key: str = Field(
+        None,
+        max_length=256,
+        title="Api key",
+        description="Api key if needed",
+        example="ckasolg5o0001yvxuzdty0jrdckasnzjot0001p2xutk68nys8",
+    )
+    from_uid: str = Field(
+        ...,
+        max_length=255,
+        title="From UID",
+        description="Channel sender UID.",
+        example="5527999000000",
+    )
+    extra: Dict[str, Any] = Field(
+        {}, title="Extra", description="Additional data for the channel plugin."
+    )
